@@ -202,8 +202,6 @@ class LiveServer:
         self.server_thread.start()
         self.watchdog.start()
 
-        print(self.server_thread.server.url(self.host)
-                + ServerPath(self.auto_open).lstrip().posix())
         if self.auto_open is not None:
             webbrowser.open_new_tab(
                 self.server_thread.server.url(self.host)
